package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SettledMerchantsInterestsMapper;
import com.ruoyi.system.domain.SettledMerchantsInterests;
import com.ruoyi.system.service.ISettledMerchantsInterestsService;

/**
 * 商户-政策类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-07-11
 */
@Service
public class SettledMerchantsInterestsServiceImpl implements ISettledMerchantsInterestsService 
{
    @Autowired
    private SettledMerchantsInterestsMapper settledMerchantsInterestsMapper;

    /**
     * 查询商户-政策类型
     * 
     * @param id 商户-政策类型主键
     * @return 商户-政策类型
     */
    @Override
    public SettledMerchantsInterests selectSettledMerchantsInterestsById(Long id)
    {
        return settledMerchantsInterestsMapper.selectSettledMerchantsInterestsById(id);
    }

    /**
     * 查询商户-政策类型列表
     * 
     * @param settledMerchantsInterests 商户-政策类型
     * @return 商户-政策类型
     */
    @Override
    public List<SettledMerchantsInterests> selectSettledMerchantsInterestsList(SettledMerchantsInterests settledMerchantsInterests)
    {
        return settledMerchantsInterestsMapper.selectSettledMerchantsInterestsList(settledMerchantsInterests);
    }

    /**
     * 新增商户-政策类型
     * 
     * @param settledMerchantsInterests 商户-政策类型
     * @return 结果
     */
    @Override
    public int insertSettledMerchantsInterests(SettledMerchantsInterests settledMerchantsInterests)
    {
        return settledMerchantsInterestsMapper.insertSettledMerchantsInterests(settledMerchantsInterests);
    }

    /**
     * 修改商户-政策类型
     * 
     * @param settledMerchantsInterests 商户-政策类型
     * @return 结果
     */
    @Override
    public int updateSettledMerchantsInterests(SettledMerchantsInterests settledMerchantsInterests)
    {
        return settledMerchantsInterestsMapper.updateSettledMerchantsInterests(settledMerchantsInterests);
    }

    /**
     * 批量删除商户-政策类型
     * 
     * @param ids 需要删除的商户-政策类型主键
     * @return 结果
     */
    @Override
    public int deleteSettledMerchantsInterestsByIds(Long[] ids)
    {
        return settledMerchantsInterestsMapper.deleteSettledMerchantsInterestsByIds(ids);
    }

    /**
     * 删除商户-政策类型信息
     * 
     * @param id 商户-政策类型主键
     * @return 结果
     */
    @Override
    public int deleteSettledMerchantsInterestsById(Long id)
    {
        return settledMerchantsInterestsMapper.deleteSettledMerchantsInterestsById(id);
    }
}
