package com.ruoyi.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SettledMerchantsInterests;
import com.ruoyi.system.service.ISettledMerchantsInterestsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商户-政策类型Controller
 * 
 * @author ruoyi
 * @date 2022-07-11
 */
@RestController
@RequestMapping("/system/interests")
public class SettledMerchantsInterestsController extends BaseController
{
    @Autowired
    private ISettledMerchantsInterestsService settledMerchantsInterestsService;

    /**
     * 查询商户-政策类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:interests:list')")
    @GetMapping("/list")
    public TableDataInfo list(SettledMerchantsInterests settledMerchantsInterests)
    {
        startPage();
        List<SettledMerchantsInterests> list = settledMerchantsInterestsService.selectSettledMerchantsInterestsList(settledMerchantsInterests);
        return getDataTable(list);
    }

    /**
     * 导出商户-政策类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:interests:export')")
    @Log(title = "商户-政策类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SettledMerchantsInterests settledMerchantsInterests)
    {
        List<SettledMerchantsInterests> list = settledMerchantsInterestsService.selectSettledMerchantsInterestsList(settledMerchantsInterests);
        ExcelUtil<SettledMerchantsInterests> util = new ExcelUtil<SettledMerchantsInterests>(SettledMerchantsInterests.class);
        util.exportExcel(response, list, "商户-政策类型数据");
    }

    /**
     * 获取商户-政策类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:interests:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(settledMerchantsInterestsService.selectSettledMerchantsInterestsById(id));
    }

    /**
     * 新增商户-政策类型
     */
    @PreAuthorize("@ss.hasPermi('system:interests:add')")
    @Log(title = "商户-政策类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SettledMerchantsInterests settledMerchantsInterests)
    {
        return toAjax(settledMerchantsInterestsService.insertSettledMerchantsInterests(settledMerchantsInterests));
    }

    /**
     * 修改商户-政策类型
     */
    @PreAuthorize("@ss.hasPermi('system:interests:edit')")
    @Log(title = "商户-政策类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SettledMerchantsInterests settledMerchantsInterests)
    {
        return toAjax(settledMerchantsInterestsService.updateSettledMerchantsInterests(settledMerchantsInterests));
    }

    /**
     * 删除商户-政策类型
     */
    @PreAuthorize("@ss.hasPermi('system:interests:remove')")
    @Log(title = "商户-政策类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(settledMerchantsInterestsService.deleteSettledMerchantsInterestsByIds(ids));
    }
}
